@@ -17,7 +17,7 @@ class dbhelper(mongodbclient):
 
     def setCollection(self, collectionName):
         try:
-            if self.db:
+            #if self.db:
                 self.collection = self.db[collectionName]
         except Exception as e:
             raise e
@@ -38,39 +38,39 @@ class dbhelper(mongodbclient):
                 example:save([model1,model2...,modeln])\r\n
         '''
         try:
-            if self.collection:
+            #if self.collection:
                 if flag.lower() == "one":
                     return self.collection.insert_one(args)
                 elif flag.lower() == "many":
                     return self.collection.insert_many(args)
-            return None
+            #return None
         except Exception as e:
             raise e
 
     def update(self, query, args):
         try:
-            if self.collection:
+            #if self.collection:
                 return self.collection.update(query, {'$set': args})
-            return None
+            #return None
         except Exception as e:
             raise e
 
     def remove(self, query=None):
         try:
-            if self.collection:
+            #if self.collection:
                 if query:
                     return self.collection.remove(query)
                 else:
                     return self.collection.remove()
-            return None
+            #return None
         except Exception as e:
             raise e
 
     def findOne(self, query):
         try:
-            if self.collection:
+            #if self.collection:
                 return self.collection.find_one(query)
-            return None
+            #return None
         except Exception as e:
             raise e
 
@@ -82,7 +82,7 @@ class dbhelper(mongodbclient):
             **kwargs: { 'query'= usr_query_str, 'limit'= usr_limit}
         '''
         try:
-            if self.collection:
+            #if self.collection:
                 if "query" in kwargs:
                     if "limit" in kwargs:
                         return self.collection.find(kwargs["query"]).limit(kwargs["limit"])
@@ -102,7 +102,7 @@ class dbhelper(mongodbclient):
             **kwargs: { 'query': usr_query_str, 'pagesize': usr_pagesize, 'pageno': pageno}
         '''
         try:
-            if self.collection:
+            #if self.collection:
                 if "query" in kwargs:
                     if ("pagesize" in kwargs) and ("pageno" in kwargs):
                         m_skip = (int(kwargs['pageno'])-1) * pagesize
