@@ -23,6 +23,8 @@ def translateDict2queryStr(post_data: any, enCoding="utf-8"):
                 post_data_params += k + "=" + json.dumps(v)
             elif isinstance(v, str):
                 post_data_params += k + "=" + parse.quote(str(v))
+            elif isinstance(v,int):
+                post_data_params += k + "=" + str(v)
             else:
                 post_data_params + k + "=" + v
             m_count += 1
@@ -84,6 +86,7 @@ def GET(
             m_params_data_str = serializePostData(
                 translateDict2queryStr(post_data,enCoding=charset), isBytes=False, enCoding=charset
             )
+            m_params_data_str=m_params_data_str if isinstance(m_params_data_str,str) else str(m_params_data_str,charset)
             if uri.find("?") > -1:
                 uri += "&" + m_params_data_str
             else:
@@ -137,11 +140,17 @@ def POST(
                 post_data = serializePostData(
                 translateDict2queryStr(post_data,enCoding=charset), isBytes=False, enCoding=charset
                 )
-            else:
+            elif content_type==ContentType.JSON:
                 post_data= serializePostData(post_data=post_data,enCoding=charset)
+            elif content_type==ContentType.FORMDATA:
+                pass
+            elif content_type== ContentType.XML:
+                pass
+            else:
+                raise Exception('content type error.')
         if http_headers:
             http_headers = requestContentType(http_headers, content_type)
-            req = request.Request(uri, data=post_data, headers=http_headers)
+            req = request.Request(uri, data=post_data, headers=http_headers,method="POST")
         else:
             req = request.Request(uri, data=post_data, method="POST")
         with request.urlopen(req, timeout=time_out) as response:
