@@ -21,7 +21,7 @@ from threading import Lock
 from threading import Event as ThreadEvent
 from urllib.parse import urlparse
 from io import StringIO, BytesIO
-from TDhelper.Cache.pools import pools
+from TDhelper.cache.pools import pools
 from TDhelper.network.http.http_helper import m_http
 from TDhelper.network.http.status.M3U8_STATUS import M3U8_STATUS
 
